@@ -24,7 +24,7 @@ o      o  _-_-_-_- NotionConnector.py
 
 import notion
 from notion.client import NotionClient
-from . import NotionPage
+from .notion_page import NotionPage
 
 class NotionConnector :
     token = ''
